from abc import ABC
from abc import abstractmethod


class Trade(ABC):

    @abstractmethod
    def __init__(self,
                 symbol: str,
                 lot: float,
                 stop_loss,
                 take_profit
                 ):
        self.symbol = symbol.upper()
        self.lot = lot
        self.stop_loss = stop_loss
        self.take_profit = take_profit

        self._trade_allowed = False

        self.trade_direction = None  # 'buy', 'sell', or None for no position
        self.position_check()

    @abstractmethod
    def open_buy(self):
        ...

    @abstractmethod
    def open_sell(self):
        ...

    @abstractmethod
    def position_open(self, buy: bool, sell: bool):
        if self._trade_allowed and self.trade_direction is None:
            if buy and not sell:
                self.open_buy()
                self.position_check()

            if sell and not buy:
                self.open_sell()
                self.position_check()

    @abstractmethod
    def position_close(self):
        if self.trade_direction == 'buy':
            self.open_sell()
            self.position_check()

        elif self.trade_direction == 'sell':
            self.open_buy()
            self.position_check()

    @abstractmethod
    def position_check(self):
        ...



from abc import ABC
from abc import abstractmethod


class Tick(ABC):

    @abstractmethod
    def __init__(self, symbol: str):

        self._symbol = symbol

        self.time = None
        self.bid = None
        self.ask = None
        self.last = None
        self.volume = None

    @abstractmethod
    def get_new_tick(self):
        ...



import pathlib
import setuptools

long_description = (pathlib.Path(__file__).parent / "README.md").read_text()

with open("requirements.txt", "r") as requirements_file:
    requirements = requirements_file.readlines()


setuptools.setup(
    name='abstractEasyT',
    version='0.2.1',
    license='MIT',
    author="Joao Paulo Euko",
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    install_requires=[requirement for requirement in requirements],
)



from abc import ABC
from abc import abstractmethod

from abstractEasyT.timeframe import TimeFrame


class Rates(ABC):

    @abstractmethod
    def __init__(self,
                 symbol: str,
                 timeframe: TimeFrame,
                 count):

        self._timeframe = timeframe
        self._symbol = symbol.upper()
        self._count = count

        self.time = None
        self.open = None
        self.high = None
        self.low = None
        self.close = None
        self.tick_volume = None

    @abstractmethod
    def update_rates(self):
        ...
